2
0

Fixed test case for GFX900

[ROCm/hip commit: 9af0f9cbc1]
Este cometimento está contido em:
Rahul Garg
2017-11-16 09:34:52 +05:30
ascendente d0ee6e00fe
cometimento 5de28551c1
+1 -1
Ver ficheiro
@@ -26,7 +26,7 @@ THE SOFTWARE.
#define HALF_SIZE 64*sizeof(__half)
#define HALF2_SIZE 64*sizeof(__half2)
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX803__
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__
__global__ void __halfMath(hipLaunchParm lp, __half *A, __half *B, __half *C) {
int tx = hipThreadIdx_x;